California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance Activity Propositions & Ballot Measures
Election Cycle: 2021 through 2022 Historical
All of the campaign committees that have organized to support or oppose propositions and ballot measures on California's statewide ballot are available here. Click below on the proposition or ballot measure to learn who is involved in the campaign to win your vote on Election Day.
Upcoming Elections
NOVEMBER 8, 2022, GENERAL
7 Measures
PROPOSITION 001 - SCA 10 (RESOLUTION CHAPTER 97, STATUTES OF 2022) ATKINS. REPRODUCTIVE FREEDOM.
PROPOSITION 026 - AUTHORIZES NEW TYPES OF GAMBLING. INITIATIVE CONSTITUTIONAL AND STATUTORY AMENDMENT.
PROPOSITION 027 - ALLOWS ONLINE AND MOBILE SPORTS WAGERING. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE.
PROPOSITION 028 - PROVIDES ADDITIONAL FUNDING FOR ARTS AND MUSIC EDUCATION IN PUBLIC SCHOOLS. INITIATIVE STATUTE.
PROPOSITION 029 - REQUIRES ON-SITE LICENSED MEDICAL PROFESSIONAL AT KIDNEY DIALYSIS CLINICS AND ESTABLISHES OTHER STATE REQUIREMENTS. INITIATIVE STATUTE.
PROPOSITION 030 - PROVIDES FUNDING FOR PROGRAMS TO REDUCE GREENHOUSE GAS EMISSIONS BY INCREASING TAX ON PERSONAL INCOME OVER $2 MILLION. INITIATIVE STATUTE.
PROPOSITION 031 - REFERENDUM CHALLENGING A 2020 LAW PROHIBITING RETAIL SALE OF CERTAIN FLAVORED TOBACCO PRODUCTS.
Prior Elections
SEPTEMBER 14, 2021, SPECIAL ELECTION
1 Measure
GOVERNOR - SPECIAL RECALL ELECTION